chicken_turtle_util.logging
===========================

.. automodule:: chicken_turtle_util.logging

.. autosummary::
   :nosignatures:

   configure
   set_level

.. autofunction:: configure
.. autofunction:: set_level
